/*****************************************************************************
 *
 *  BoolListParameter.h                         XMM Science Analysis Subsystem
 *
 *  Boolean-list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolListParameter.h,v 1.12 2001/03/28 19:20:34 jbakker Exp $
 *
 *****************************************************************************/

#ifndef BOOLLISTPARAMETER_H
#define BOOLLISTPARAMETER_H

#include "Optional.h"
#include "Parameter.h"           // SAS headers

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class BoolListParameter
//================================================================

class BoolListParameter : public Parameter
{
public:
    // Construction
    BoolListParameter* clone() { return new BoolListParameter(*this); }

    // Value
    vector<int>  boolListValue() const {return _value;}
    bool         setNewValue(const string& value);
    bool         setValue(const vector<int>& value);
    int          size() const;
    ParamType    getType() const {return Parameter::BoolList;}
    const char*  getTypeName() const { return "bool_list"; }

    // Default
    vector<int>  defaultValue() const {return _default;}
    bool         setNewDefault(const string& value);
    bool         setDefault(const vector<int>& value);
    void         revertToDefault();

    // Formatting
    string       asString() const;
    string       defaultAsString() const;

    // Validation
    virtual bool validate() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.boolListValue());}

    // Parsing
    bool parse(const string& str, vector<int>& value);

    // Validation
    bool isValid(const vector<int>& n) const;

    // Member data
    vector<int> _value;
    vector<int> _default;
};

#endif
