/*****************************************************************************
 *
 *  BoolParameter.cc                            XMM Science Analysis Subsystem
 *
 *  Boolean task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolParameter.cc,v 1.10 2001/03/28 19:20:35 jbakker Exp $
 *
 *****************************************************************************/

#include <iostream>             // C++ headers
#include <string>

#include "BoolParameter.h"        // SAS headers
#include "StringToken.h"
#include <errstr.h>


//================================================================
//  Class BoolParameter
//================================================================

/*** Format the parameter value as a string ***/

string BoolParameter::asString() const
{
    return (_value ? "yes" : "no");
}


/*** Format the default value as a string ***/

string BoolParameter::defaultAsString() const
{
    return (_default ? "yes" : "no");
}


/***  Parse string representation and assign to 'value' if it is valid ***/

bool BoolParameter::parse(const string& str, bool& value)
{
    bool ok = true;
    StringToken t(str);
    bool n = t.asBool();
    if(t.isValid())
        value = n;
    else {
      errstr << "Parameter '" << _name << "'" << Sas::error("ParamWrongType");
      ok = false;
    }
    return ok;
}


/*** Revert to default value ***/

void BoolParameter::revertToDefault()
{
    _value = _default;
    notifyView();
}


/*** Set the parameter to the specified value ***/

bool BoolParameter::setValue(bool value)
{
    _value = value;
    setDefined();
    notifyView();
    return true;
}


/*** Set the default to the specified value ***/

bool BoolParameter::setDefault(bool value)
{
    _default = value;
    return true;
}


/*** Set the value, specified as a string ***/

bool BoolParameter::setNewValue(const string& str)
{
    bool value = false;
    bool ok = parse(str, value) && setValue(value);

    if(!ok)
      errstr << "Parameter '" << _name << "' cannot be assigned new value '"
	     << str << "'" << Sas::error("ParamNotAssigned");

    notifyView();
    return true;
}


/***  Set the default, specified as a string ***/

bool BoolParameter::setNewDefault(const string& str)
{
    bool value = false;
    bool ok = parse(str, value) && setDefault(value);

    if(!ok)
      errstr << "Parameter '" << _name << "' cannot be assigned default value "
	     << str << Sas::error("ParamNotAssigned");

    return true;
}
