/*****************************************************************************
 *
 *  ParameterInfo.h                             XMM Science Analysis Subsystem
 *
 *  Information about parameters of a task
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: ParameterInfo.h,v 1.12 2001/03/28 19:20:36 jbakker Exp $
 *
 *****************************************************************************/

#ifndef PARAMINFO_H
#define PARAMINFO_H

#include "Parameter.h"            // Application headers

#include <iostream>             // C++ headers
#include <string>
#include <list>
#include <vector>
#include <map>


//================================================================
//  Class ParameterInfo
//================================================================

class ParameterInfo
{
public:

    // Types
    typedef map<string, Parameter*, less<string> > ParamMap;

    // Constructors and destructors
    ParameterInfo();
    ParameterInfo(const ParameterInfo&);
    ~ParameterInfo();

    // Assignment operator
    ParameterInfo& operator=(const ParameterInfo& rhs);

    // Adding parameters
    void addParameter(Parameter* param);

    // Command line
    string asCommandLine() const;
    vector<string> asArgumentList() const;
    void parseCommandLine(int& argc, char** argv);

    // Task name
    string taskName() const { return _taskName; }
    void setTaskName(const string& name);

    // Accessors
    list<string> names() const;
    Parameter* operator[](const string& name);
    Parameter* parameter(const string& name, bool alertError=false);

    // Defaults
    void revertToDefault();

    // Validation
    void checkMandatoryParameters();

    // Stream I/O
    friend ostream& operator<<(ostream& os, const ParameterInfo& p);
    void writeHelpToStream(ostream& os) const;

private:

    // Command line
    void parseSASCommandLine(int& argc, char** argv);
    void parsePCSCommandLine(int& argc, char** argv);

    void copy(const ParameterInfo& rhs);

    // Member data
    string       _taskName;
    ParamMap     _map;
    list<string> _nameList;     // Ordered list of map keys
};

#endif

