/*****************************************************************************
 *
 *  SpecialStringListParameters.h               XMM Science Analysis Subsystem
 *
 *  Subclasses of StringListParameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SpecialStringListParameters.h,v 1.2 2001/03/28 19:20:37 jbakker Exp $
 *
 *****************************************************************************/

#ifndef SPECIALSTRINGLISTPARAMETERS_H
#define SPECIALSTRINGLISTPARAMETERS_H

#include "StringListParameter.h"

#include <string>
#include <vector>


//================================================================
//  Class FileNameListParameter
//================================================================

class FileNameListParameter : public StringListParameter
{
public:

    FileNameListParameter* clone() { return new FileNameListParameter(*this); }
    ParamType getType() const {return Parameter::FileNameList;}
    const char* getTypeName() const { return "filename_list"; }
};


//================================================================
//  Class DirectoryListParameter
//================================================================

class DirectoryListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::DirectoryList;}
    const char* getTypeName() const { return "directory_list"; }
    DirectoryListParameter* clone() { return new DirectoryListParameter(*this); }
};


//================================================================
//  Class DataSetListParameter
//================================================================

class DataSetListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::DataSetList;}
    const char* getTypeName() const { return "dataset_list"; }
    DataSetListParameter* clone() { return new DataSetListParameter(*this); }
};


//================================================================
//  Class BlockListParameter
//================================================================

class BlockListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::BlockList;}
    const char* getTypeName() const { return "block_list"; }
    BlockListParameter* clone() { return new BlockListParameter(*this); }
};


//================================================================
//  Class TableListParameter
//================================================================

class TableListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::TableList;}
    const char* getTypeName() const { return "table_list"; }
    TableListParameter* clone() { return new TableListParameter(*this); }
};


//================================================================
//  Class ArrayListParameter
//================================================================

class ArrayListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::ArrayList;}
    const char* getTypeName() const { return "array_list"; }
    ArrayListParameter* clone() { return new ArrayListParameter(*this); }
};


//================================================================
//  Class ColumnListParameter
//================================================================

class ColumnListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::ColumnList;}
    const char* getTypeName() const { return "column_list"; }
    ColumnListParameter* clone() { return new ColumnListParameter(*this); }
};


//================================================================
//  Class PlaneListParameter
//================================================================

class PlaneListParameter : public StringListParameter
{
public:

    ParamType getType() const {return Parameter::PlaneList;}
    const char* getTypeName() const { return "plane_list"; }
    PlaneListParameter* clone() { return new PlaneListParameter(*this); }
};


#endif
