/*****************************************************************************
 *
 *  StringParameter.h                           XMM Science Analysis Subsystem
 *
 *  String task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringParameter.h,v 1.9 2000/10/25 12:33:35 jbakker Exp $
 *
 *****************************************************************************/

#ifndef STRINGPARAMETER_H
#define STRINGPARAMETER_H

#include "Parameter.h"           // headers
#include <string>


//================================================================
//  Class StringParameter
//================================================================

class StringParameter : public Parameter
{
public:
    // Construction
    StringParameter* clone() { return new StringParameter(*this); }

    // Value
    const string&  stringValue() const { return _value; }
    bool           setNewValue(const string& value);
    virtual bool   setValue(const string& value);
    virtual bool   setValue(const char* s) { return setValue(string(s)); }
    ParamType      getType() const {return Parameter::String;}
    const char*    getTypeName() const { return "string"; }

    // Default
    const string&  defaultValue() const {return _default;}
    bool           setNewDefault(const string& value);
    virtual bool   setDefault(const string& value);
    void           revertToDefault();

    // Constraint
    void setChoices(const list<string>& choices) { _choices = choices; }
    const list<string>& getChoices() const {return _choices;}

    // Formatting
    virtual string asString() const;
    string     defaultAsString() const;

    // Validation
    virtual bool   validate() const;

protected:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.stringValue());}

    // Parsing
    bool parse(const string& str, string& value);

    // Validation
    virtual bool isValid(const string& value) const;
    virtual void reportRangeError(const string& valueString);
    virtual void writeConstraint(ostream&) const;

    // Member data
    string _value;
    string _default;

private:
    // Member data
    list<string> _choices;
};

#endif

