/****************************************************************************
 *
 *  testapierror.cc                            XMM Science Analysis Subsystem
 *
 *  Test various errors in API calls
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testapierror.cc,v 1.5 2001/03/28 19:20:39 jbakker Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>

#include <cstdlib>                  // C headers

#include <iostream>                // C++ headers
#include <string>
#include <vector>

#include <errstr.h>

int main(int argc, char* argv[])
{
    // Get argument specifying test to be performed
    if(argc != 2)
    {
        cerr << "Testcmdline requires one argument" << endl;
        ::exit(1);
    }
    int testno = atoi(argv[1]);
    cout << argv[0] << " test " << testno << endl;

    string taskname(argv[0]);
    errHandler.name(taskname);

    openParameters("testparamcc");

    switch(testno)
    {
    case 0:
        // Attempt to access non-existant parameter
        cout << intParameter("nonexistant") << endl;
	break;

    case 1:
        // Attempt to access parameter with wrong type
        cout << intParameter("sval") << endl;
	break;

    case 2:
        // Attempt to index a scalar parameter
        cout << intParameter("ival",2) << endl;
        break;
      
    case 3:
        // Attempt to sets parameter with incorrect type
        setParameter("ival",3.14);
        break;

    case 4:
        // Attempt to use out-of-range array index
        cout << intParameter("ilist",10) << endl;
        break;

    case 5:
        // Attempt to call parameterCount for a scalar parameter
        cout << parameterCount("ival") << endl;
        break;

    case 6:
        // Attempt to setParameter with out-of-range value
        setParameter("ival",200);
        break;

    case 7:
        // Attempt to set non-existant parameter
        setParameter("nonExistant",42);
        break;

    case 8: {
        // Attempt to access non-existant vector
        vector<int> vi1 = intListParameter("nonexistant");
	break;
    }
    case 9: {
        // Attempt to access vector with wrong type
        vector<int> vi2 = intListParameter("slist");
	break;
    }

    default:
        cerr << "Invalid test number = " << testno << endl;
        break;
    }

    closeParameters();

    return 0;
}
