! Program: test_param
!
! Author: Jon Brumfitt
!
! Description: Test F90 API of param package
! 
! Comments: 
! 
! $Id: testparamf90.f90,v 1.2 1998/09/10 07:50:52 jbrumfit Exp $
! 
program test_param

  use errorHandling
  use param
  
  implicit none 
  
  character(len=128) :: sval, fval
  logical :: bval0, bval1
  integer :: ival, i, n
  real :: rval

  real :: epsilon = 1e-5

  call openParameters( "testparamcc" )


  !----- Boolean parameter -----

  bval0 = booleanParameter("bval0")
  bval1 = booleanParameter("bval1")
  write(*,*) 'bval0  = ', bval0
  write(*,*) 'bval1  = ', bval1
  if (booleanParameter("bval0")) &
       call error("booleanParameter","invalid value for booleanParameter")
  if (.not. booleanParameter("bval1")) &
       call error("booleanParameter","invalid value for bval")


  !----- Integer parameter -----

  ival = intParameter("ival")
  write(*,*) 'ival   = ', ival
  if (intParameter("ival") /= 42) &
       call error("intParameter","invalid value for ival")


  !----- Real parameter -----

  rval = realParameter("rval")
  write(*,*) 'rval   = ', rval
  if (abs(realParameter("rval") - 1.23e-5) > 1.23e-5 * epsilon) &
       call error("realParameter","invalid value for rval")


  !----- String parameter -----

  sval = stringParameter("sval")
  write(*,*) 'sval   = "', trim(sval), '"'
  if (trim(stringParameter("sval")) /= trim("ab #,cd")) &
       call error("stringParameter","invalid value for sval")


  !----- Filename parameter -----

  fval = stringParameter("fval")
  write(*,*) 'fval   = ', fval
  if (trim(stringParameter("fval")) /= "temp") &
       call error("stringParameter","invalid value for fval")

  
  !----- Boolean parameter list -----
  
  n = parameterCount("blist")
  write(*,*) 'size(blist)   = ', n
  if(n /= 3) &
       call error("boolList","Incorrect length for blist")
  do i = 0, n-1
     write(*,*) 'blist(',i,')  = ', booleanParameter("blist",i)
  end do
  if(booleanParameter("blist",0) .NEQV. .TRUE.) &
       call error("boolList","invalid value for blist")
  if(booleanParameter("blist",1) .NEQV. .TRUE.) &
       call error("boolList","invalid value for blist")
  if(booleanParameter("blist",2) .NEQV. .FALSE.) &
       call error("boolList","invalid value for blist")


  !----- Integer parameter list -----

  n = parameterCount("ilist")
  write(*,*) 'size(ilist)   = ', n
  if(n /= 3) &
       call error("intList","Incorrect length for ilist")
  do i = 0, n-1
     write(*,*) 'ilist(',i,')  = ', intParameter("ilist",i)
  end do
  if(intParameter("ilist",0) /= 5) &
       call error("intList","invalid value for ilist")
  if(intParameter("ilist",1) /= 17) &
       call error("intList","invalid value for ilist")
  if(intParameter("ilist",2) /= -2) &
       call error("intList","invalid value for ilist")


  !----- Real parameter list -----

  n = parameterCount("rlist")
  write(*,*) 'size(rlist)   = ', n
  if(n /= 2) &
       call error("realList","Incorrect length for rlist")
  do i = 0, n-1
     write(*,*) 'rlist(',i,')  = ', realParameter("rlist",i)
  end do
  if(abs(realParameter("rlist",0) - (-1.2e-3)) > 1.2e-3 * epsilon) &
       call error("realList","invalid value for rlist")
  write(*,*) 'xxx           = ',abs(realParameter("rlist",0) - (-1.2e-3))
  if(abs(realParameter("rlist",1) - 3.4e3) > 3.4e3 * epsilon) &
       call error("realList","invalid value for rlist")


  !----- String parameter list -----
  
  n = parameterCount("slist")
  write(*,*) 'size(slist)   = ', n
  if(n /= 3) &
       call error("stringList","Incorrect length for slist")
  do i = 0, n-1
     write(*,*) 'slist(',i,')  = ', trim(stringParameter("slist",i))
  end do
  if(trim(stringParameter("slist",0)) /= trim("ab,# cd")) &
       call error("stringList","invalid value for slist")
  if(trim(stringParameter("slist",1)) /= "") &
       call error("stringList","invalid value for slist")
  if(trim(stringParameter("slist",2)) /= trim("ef")) &
       call error("stringList","invalid value for slist")


  !----- Filename parameter list -----

  n = parameterCount("flist")
  write(*,*) 'size(flist)   = ', n
  if(n /= 2) &
       call error("filenameList","Incorrect length for flist")
  do i = 0, n-1
     write(*,*) 'flist(',i,')  = ', trim(stringParameter("flist",i))
  end do
  if(trim(stringParameter("flist",0)) /= "/tmp/t1") &
       call error("filenameList","invalid value for flist")
  if(trim(stringParameter("flist",1)) /= "t2") &
       call error("filenameList","invalid value for flist")

  
call closeParameters()

end program test_param
